#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-5dxlhZ08Z9ZIfgEfcsxvDd
key:                  coinbase-pro-0.9.3.2-5dxlhZ08Z9ZIfgEfcsxvDd
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  90805e5c4f0670ea8903af90f519bd84
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-5dxlhZ08Z9ZIfgEfcsxvDd
depends:
    HsOpenSSL-0.11.7.10-IEMoguQPBxoKPVAejAQPhi
    aeson-2.2.2.0-EED32RMVwDLAiFjSZ5pcFd
    aeson-casing-0.2.0.0-JfXaZffxU9qAPc9SSaLF7R
    async-2.2.6-Gh1F42mE1aYJ8FizPlAhTn base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-4ywVCh1OtfUIJDDk9b4w1J exceptions-0.10.7
    http-api-data-0.6.1-IgebMWwwxGG6Yff4RfOCfK
    http-client-0.7.19-Fo3I0O6VQkeFqNh8n8YCCa
    http-client-tls-0.3.6.4-I8RiwvlKvhsGMxVJFF7Qks
    http-streams-0.8.9.9-C2SvsZMU8aBAJppqyI8Y3T
    http-types-0.12.4-3SRp0qHlnI76ALPv5yfzvg
    io-streams-1.5.2.2-ESWINYNhzrk41GfivgfJXX
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8bVD9DiLdB7AtkTNcfBrB8
    servant-0.20.3.0-LByDWFyIJ26GG48his2Ijo
    servant-client-0.20.3.0-EM1nSfLTm9dHyJThoUX8Mv
    servant-client-core-0.20.3.0-JcF31yFdWOH57YJsa4PbpS
    tasty-1.5.3-AQn0zCg8FJFuC8HnfahFb
    tasty-hunit-0.10.2-Bc824iLtQotAA5WcAZG7fz text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-GRKHzqeC2lVD3BycRrG6K5
    unordered-containers-0.2.20.1-9xqafn4Eq4w4BZS2LI6Zwa
    uuid-1.3.16.1-2ODZ3TnzOBgFwbnChbOSwG
    vector-0.13.2.0-GxJ3o7ubGCR5jPPfpyxiRl
    websockets-0.12.7.3-AeDA16brjEHFyjeuiG307p
    wuss-2.0.1.7-5kxXXJAqjtpLOA1UQ3FYA

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

